
From: Andrew Morton <akpm@osdl.org>

- Reduce inlining

- CodingStyle.

Cc: Jan Kara <jack@suse.cz>
Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 fs/jbd/checkpoint.c |   36 +++++++++++++++++++-----------------
 linux/jbd.h         |    0 
 2 files changed, 19 insertions(+), 17 deletions(-)

diff -puN fs/jbd/checkpoint.c~jbd-split-checkpoint-lists-tweaks fs/jbd/checkpoint.c
--- 25/fs/jbd/checkpoint.c~jbd-split-checkpoint-lists-tweaks	Tue Jun 28 15:39:37 2005
+++ 25-akpm/fs/jbd/checkpoint.c	Tue Jun 28 15:39:37 2005
@@ -29,7 +29,7 @@
  * Called with j_list_lock held.
  */
 
-static inline void __buffer_unlink_first(struct journal_head *jh)
+static void __buffer_unlink_first(struct journal_head *jh)
 {
 	transaction_t *transaction;
 
@@ -242,13 +242,13 @@ static int __process_buffer(journal_t *j
 	int ret = 0;
 
 	if (buffer_locked(bh)) {
-		atomic_inc(&bh->b_count);
+		get_bh(bh);
 		spin_unlock(&journal->j_list_lock);
 		jbd_unlock_bh_state(bh);
 		wait_on_buffer(bh);
 		/* the journal_head may have gone by now */
 		BUFFER_TRACE(bh, "brelse");
-		__brelse(bh);
+		put_bh(bh);
 		ret = 1;
 	}
 	else if (jh->b_transaction != NULL) {
@@ -268,7 +268,7 @@ static int __process_buffer(journal_t *j
 		spin_unlock(&journal->j_list_lock);
 		jbd_unlock_bh_state(bh);
 		journal_remove_journal_head(bh);
-		__brelse(bh);
+		put_bh(bh);
 		ret = 1;
 	}
 	else {
@@ -336,8 +336,8 @@ restart:
 	 * done (maybe it's a new transaction, but it fell at the same
 	 * address).
 	 */
- 	if (journal->j_checkpoint_transactions == transaction
-		|| transaction->t_tid == this_tid) {
+ 	if (journal->j_checkpoint_transactions == transaction ||
+			transaction->t_tid == this_tid) {
 		int batch_count = 0;
 		struct buffer_head *bhs[NR_BATCH];
 		struct journal_head *jh;
@@ -354,7 +354,7 @@ restart:
 				break;
 			}
 			retry = __process_buffer(journal, jh, bhs,
-				&batch_count);
+						&batch_count);
 			if (!retry &&
 			    lock_need_resched(&journal->j_list_lock)) {
 				spin_unlock(&journal->j_list_lock);
@@ -375,8 +375,10 @@ restart:
 			spin_lock(&journal->j_list_lock);
 			goto restart;
 		}
-		/* Now we have cleaned up the first transaction's checkpoint
-		 * list. Let's clean up the second one. */
+		/*
+		 * Now we have cleaned up the first transaction's checkpoint
+		 * list.  Let's clean up the second one.
+		 */
 		__wait_cp_io(journal, transaction);
 	}
 out:
@@ -503,10 +505,9 @@ static int journal_clean_one_cp_list(str
 			}
 		}
 		/*
-		 * This function only frees up some memory
-		 * if possible so we dont have an obligation
-		 * to finish processing. Bail out if preemption
-		 * requested:
+		 * This function only frees up some memory if possible so we
+		 * dont have an obligation to finish processing. Bail out if
+		 * preemption requested:
 		 */
 		if (need_resched())
 			return freed;
@@ -545,10 +546,11 @@ int __journal_clean_checkpoint_list(jour
 			goto out;
 		if (released)
 			continue;
-		/* It is essential that we are as careful as in the case of
-		   t_checkpoint_list with removing the buffer from the list
-		   as we can possibly see not yet submitted buffers on
-		   io_list */
+		/*
+		 * It is essential that we are as careful as in the case of
+		 * t_checkpoint_list with removing the buffer from the list as
+		 * we can possibly see not yet submitted buffers on io_list
+		 */
 		ret += journal_clean_one_cp_list(transaction->
 				t_checkpoint_io_list, &released);
 		if (need_resched())
diff -puN include/linux/jbd.h~jbd-split-checkpoint-lists-tweaks include/linux/jbd.h
_
